==> servicecatalog-2.10.44-sources.jar: software/amazon/awssdk/services/servicecatalog/paginators/ListOrganizationPortfolioAccessIterable.java <==
/*
 * Copyright 2015-2020 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */

package software.amazon.awssdk.services.servicecatalog.paginators;

import java.util.Iterator;
import software.amazon.awssdk.annotations.Generated;
import software.amazon.awssdk.core.pagination.sync.PaginatedResponsesIterator;
import software.amazon.awssdk.core.pagination.sync.SdkIterable;
import software.amazon.awssdk.core.pagination.sync.SyncPageFetcher;
import software.amazon.awssdk.core.util.PaginatorUtils;
import software.amazon.awssdk.services.servicecatalog.ServiceCatalogClient;
import software.amazon.awssdk.services.servicecatalog.model.ListOrganizationPortfolioAccessRequest;
import software.amazon.awssdk.services.servicecatalog.model.ListOrganizationPortfolioAccessResponse;

/**
 * <p>
 * Represents the output for the
 * {@link software.amazon.awssdk.services.servicecatalog.ServiceCatalogClient#listOrganizationPortfolioAccessPaginator(software.amazon.awssdk.services.servicecatalog.model.ListOrganizationPortfolioAccessRequest)}
 * operation which is a paginated operation. This class is an iterable of
 * {@link software.amazon.awssdk.services.servicecatalog.model.ListOrganizationPortfolioAccessResponse} that can be used
 * to iterate through all the response pages of the operation.
 * </p>
 * <p>
 * When the operation is called, an instance of this class is returned. At this point, no service calls are made yet and
 * so there is no guarantee that the request is valid. As you iterate through the iterable, SDK will start lazily
 * loading response pages by making service calls until there are no pages left or your iteration stops. If there are
 * errors in your request, you will see the failures only after you start iterating through the iterable.
 * </p>
 *
 * <p>
 * The following are few ways to iterate through the response pages:
 * </p>
 * 1) Using a Stream
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.servicecatalog.paginators.ListOrganizationPortfolioAccessIterable responses = client.listOrganizationPortfolioAccessPaginator(request);
 * responses.stream().forEach(....);
 * }
 * </pre>
 *
 * 2) Using For loop
 * 
 * <pre>
 * {
 *     &#064;code
 *     software.amazon.awssdk.services.servicecatalog.paginators.ListOrganizationPortfolioAccessIterable responses = client
 *             .listOrganizationPortfolioAccessPaginator(request);
 *     for (software.amazon.awssdk.services.servicecatalog.model.ListOrganizationPortfolioAccessResponse response : responses) {
 *         // do something;
 *     }
 * }
 * </pre>
 *
 * 3) Use iterator directly
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.servicecatalog.paginators.ListOrganizationPortfolioAccessIterable responses = client.listOrganizationPortfolioAccessPaginator(request);
 * responses.iterator().forEachRemaining(....);
 * }
 * </pre>
 * <p>
 * <b>Note: If you prefer to have control on service calls, use the
 * {@link #listOrganizationPortfolioAccess(software.amazon.awssdk.services.servicecatalog.model.ListOrganizationPortfolioAccessRequest)}
 * operation.</b>
 * </p>
 */
@Generated("software.amazon.awssdk:codegen")
public class ListOrganizationPortfolioAccessIterable implements SdkIterable<ListOrganizationPortfolioAccessResponse> {
    private final ServiceCatalogClient client;

    private final ListOrganizationPortfolioAccessRequest firstRequest;

    private final SyncPageFetcher nextPageFetcher;

    public ListOrganizationPortfolioAccessIterable(ServiceCatalogClient client,
            ListOrganizationPortfolioAccessRequest firstRequest) {
        this.client = client;
        this.firstRequest = firstRequest;
        this.nextPageFetcher = new ListOrganizationPortfolioAccessResponseFetcher();
    }

    @Override
    public Iterator<ListOrganizationPortfolioAccessResponse> iterator() {
        return PaginatedResponsesIterator.builder().nextPageFetcher(nextPageFetcher).build();
    }

    private class ListOrganizationPortfolioAccessResponseFetcher implements
            SyncPageFetcher<ListOrganizationPortfolioAccessResponse> {
        @Override
        public boolean hasNextPage(ListOrganizationPortfolioAccessResponse previousPage) {
            return PaginatorUtils.isOutputTokenAvailable(previousPage.nextPageToken());
        }

        @Override
        public ListOrganizationPortfolioAccessResponse nextPage(ListOrganizationPortfolioAccessResponse previousPage) {
            if (previousPage == null) {
                return client.listOrganizationPortfolioAccess(firstRequest);
            }
            return client.listOrganizationPortfolioAccess(firstRequest.toBuilder().pageToken(previousPage.nextPageToken())
                    .build());
        }
    }
}

==> servicecatalog-2.18.18-sources.jar: software/amazon/awssdk/services/servicecatalog/paginators/ListOrganizationPortfolioAccessIterable.java <==
/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */

package software.amazon.awssdk.services.servicecatalog.paginators;

import java.util.Iterator;
import software.amazon.awssdk.annotations.Generated;
import software.amazon.awssdk.core.pagination.sync.PaginatedResponsesIterator;
import software.amazon.awssdk.core.pagination.sync.SdkIterable;
import software.amazon.awssdk.core.pagination.sync.SyncPageFetcher;
import software.amazon.awssdk.core.util.PaginatorUtils;
import software.amazon.awssdk.services.servicecatalog.ServiceCatalogClient;
import software.amazon.awssdk.services.servicecatalog.model.ListOrganizationPortfolioAccessRequest;
import software.amazon.awssdk.services.servicecatalog.model.ListOrganizationPortfolioAccessResponse;

/**
 * <p>
 * Represents the output for the
 * {@link software.amazon.awssdk.services.servicecatalog.ServiceCatalogClient#listOrganizationPortfolioAccessPaginator(software.amazon.awssdk.services.servicecatalog.model.ListOrganizationPortfolioAccessRequest)}
 * operation which is a paginated operation. This class is an iterable of
 * {@link software.amazon.awssdk.services.servicecatalog.model.ListOrganizationPortfolioAccessResponse} that can be used
 * to iterate through all the response pages of the operation.
 * </p>
 * <p>
 * When the operation is called, an instance of this class is returned. At this point, no service calls are made yet and
 * so there is no guarantee that the request is valid. As you iterate through the iterable, SDK will start lazily
 * loading response pages by making service calls until there are no pages left or your iteration stops. If there are
 * errors in your request, you will see the failures only after you start iterating through the iterable.
 * </p>
 *
 * <p>
 * The following are few ways to iterate through the response pages:
 * </p>
 * 1) Using a Stream
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.servicecatalog.paginators.ListOrganizationPortfolioAccessIterable responses = client.listOrganizationPortfolioAccessPaginator(request);
 * responses.stream().forEach(....);
 * }
 * </pre>
 *
 * 2) Using For loop
 * 
 * <pre>
 * {
 *     &#064;code
 *     software.amazon.awssdk.services.servicecatalog.paginators.ListOrganizationPortfolioAccessIterable responses = client
 *             .listOrganizationPortfolioAccessPaginator(request);
 *     for (software.amazon.awssdk.services.servicecatalog.model.ListOrganizationPortfolioAccessResponse response : responses) {
 *         // do something;
 *     }
 * }
 * </pre>
 *
 * 3) Use iterator directly
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.servicecatalog.paginators.ListOrganizationPortfolioAccessIterable responses = client.listOrganizationPortfolioAccessPaginator(request);
 * responses.iterator().forEachRemaining(....);
 * }
 * </pre>
 * <p>
 * <b>Please notice that the configuration of PageSize won't limit the number of results you get with the paginator. It
 * only limits the number of results in each page.</b>
 * </p>
 * <p>
 * <b>Note: If you prefer to have control on service calls, use the
 * {@link #listOrganizationPortfolioAccess(software.amazon.awssdk.services.servicecatalog.model.ListOrganizationPortfolioAccessRequest)}
 * operation.</b>
 * </p>
 */
@Generated("software.amazon.awssdk:codegen")
public class ListOrganizationPortfolioAccessIterable implements SdkIterable<ListOrganizationPortfolioAccessResponse> {
    private final ServiceCatalogClient client;

    private final ListOrganizationPortfolioAccessRequest firstRequest;

    private final SyncPageFetcher nextPageFetcher;

    public ListOrganizationPortfolioAccessIterable(ServiceCatalogClient client,
            ListOrganizationPortfolioAccessRequest firstRequest) {
        this.client = client;
        this.firstRequest = firstRequest;
        this.nextPageFetcher = new ListOrganizationPortfolioAccessResponseFetcher();
    }

    @Override
    public Iterator<ListOrganizationPortfolioAccessResponse> iterator() {
        return PaginatedResponsesIterator.builder().nextPageFetcher(nextPageFetcher).build();
    }

    private class ListOrganizationPortfolioAccessResponseFetcher implements
            SyncPageFetcher<ListOrganizationPortfolioAccessResponse> {
        @Override
        public boolean hasNextPage(ListOrganizationPortfolioAccessResponse previousPage) {
            return PaginatorUtils.isOutputTokenAvailable(previousPage.nextPageToken());
        }

        @Override
        public ListOrganizationPortfolioAccessResponse nextPage(ListOrganizationPortfolioAccessResponse previousPage) {
            if (previousPage == null) {
                return client.listOrganizationPortfolioAccess(firstRequest);
            }
            return client.listOrganizationPortfolioAccess(firstRequest.toBuilder().pageToken(previousPage.nextPageToken())
                    .build());
        }
    }
}
